Struct Numeric
Source pub struct Numeric(pub String);
NUMERIC/DECIMAL type (stored as string for precision)
Create from string representation
Parse as f64 (may lose precision for very large numbers)
Parse as i64 (truncates decimal part)
Get the string representation
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Convert from PostgreSQL wire format.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Convert to PostgreSQL wire format.
Returns (bytes, oid, format_code)
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.